@@ -44,11 +44,11 @@ async fn reset_term() -> Result<(), Die> {
   Err(Die::IO(PathBuf::from("reset"), ErrorKind::NotFound))
 }
 
-pub fn stream_fzf_proc<'a>(
+pub fn stream_fzf_proc(
   bin: PathBuf,
   args: Vec<String>,
-  stream: impl Stream<Item = Result<OsString, Die>> + Unpin + Send + 'a,
-) -> impl Stream<Item = Result<(), Die>> + Send + 'a {
+  stream: impl Stream<Item = Result<OsString, Die>> + Unpin,
+) -> impl Stream<Item = Result<(), Die>> {
   let execute = format!("abort+execute:{}\x04{{+f}}", Mode::PATCH);
   let mut arguments = vec![
     "--read0".to_owned(),
@@ -76,15 +76,15 @@ pub fn stream_fzf_proc<'a>(
         |path| format!("{}", path.display()),
       ),
   );
-  fzf_env.insert("LC_ALL".to_owned(), "C-UTF8".to_owned());
+  fzf_env.insert("LC_ALL".to_owned(), "C.UTF-8".to_owned());
 
   let cmd = SubprocCommand {
     prog: bin,
     args: arguments,
     env: fzf_env,
   };
-  stream_subproc(cmd, stream).then(|line| async {
-    match line {
+  stream_subproc(cmd, stream).then(|row| async {
+    match row {
       Ok(o) => Ok(o),
       Err(Die::BadExit(_, 130)) => Err(Die::Interrupt),
       e => {
