@@ -32,7 +32,6 @@ use {
     path::PathBuf,
     pin::pin,
     process::{ExitCode, Termination},
-    sync::Arc,
     thread::available_parallelism,
   },
   subprocess::{stream_into, stream_subproc},
@@ -40,10 +39,10 @@ use {
   types::Die,
 };
 
-fn stream_sink<'a>(
+fn stream_sink(
   opts: &Options,
-  stream: impl Stream<Item = Result<OsString, Die>> + Unpin + Send + 'a,
-) -> impl Stream<Item = Result<(), Die>> + Send + 'a {
+  stream: impl Stream<Item = Result<OsString, Die>> + Unpin,
+) -> impl Stream<Item = Result<(), Die>> {
   match (&opts.action, &opts.printer) {
     (Action::FzfPreview(fzf_p, fzf_a), _) => Either::Left(Either::Left(stream_fzf_proc(
       fzf_p.clone(),
@@ -67,14 +66,13 @@ async fn consume(stream: impl Stream<Item = Result<(), Die>> + Send) -> Result<(
   });
   let out = select(
     stream
-      .filter_map(|row| async { row.err() })
+      .filter_map(|row| ready(row.err()))
       .chain(once(ready(Die::Eof))),
     int,
   );
   let mut out = pin!(out);
   match out.next().await {
     None | Some(Die::Eof) => Ok(()),
-    Some(Die::Interrupt) => Err(Die::Interrupt),
     Some(e) => Err(e),
   }
 }
@@ -83,16 +81,12 @@ async fn run(threads: usize) -> Result<(), Die> {
   let (mode, args) = parse_args();
   let input_stream = stream_in(&mode, &args).await;
   let opts = parse_opts(mode, args)?;
-  let options = Arc::new(opts);
-  let opts = options.clone();
-  let trans_stream = Box::pin(input_stream)
-    .map_ok(move |input| {
-      let opts = options.clone();
-      async move { displace(&opts, input).await }
-    })
-    .try_buffer_unordered(threads);
 
-  let out_stream = stream_sink(&opts, trans_stream);
+  let trans_stream = input_stream
+    .map_ok(|input| displace(&opts, input))
+    .try_buffer_unordered(threads);
+  let out_stream = stream_sink(&opts, trans_stream.boxed());
+
   consume(out_stream).await
 }
 
