@@ -20,9 +20,9 @@ pub struct SubprocCommand {
 
 pub fn stream_into(
   path: PathBuf,
-  writer: impl AsyncWrite + Send + Unpin,
-  stream: impl Stream<Item = Result<OsString, Die>> + Send + Unpin,
-) -> impl Stream<Item = Result<(), Die>> + Send
+  writer: impl AsyncWrite + Unpin,
+  stream: impl Stream<Item = Result<OsString, Die>> + Unpin,
+) -> impl Stream<Item = Result<(), Die>>
 where
 {
   let buf = BufWriter::new(writer);
@@ -59,10 +59,10 @@ where
   })
 }
 
-pub fn stream_subproc<'a>(
+pub fn stream_subproc(
   cmd: SubprocCommand,
-  stream: impl Stream<Item = Result<OsString, Die>> + Unpin + Send + 'a,
-) -> impl Stream<Item = Result<(), Die>> + Send + 'a {
+  stream: impl Stream<Item = Result<OsString, Die>> + Unpin,
+) -> impl Stream<Item = Result<(), Die>> {
   let subprocess = Command::new(&cmd.prog)
     .kill_on_drop(true)
     .args(&cmd.args)
